@@ -14,11 +14,13 @@ pcd_stan_path <- function() {
 .unmatched_braces <- function(line) {
   ifelse(
     grepl("{", line, fixed = TRUE),
-    length(gregexpr("{", line, fixed = TRUE)), 0
+    length(gregexpr("{", line, fixed = TRUE)),
+    0
   ) -
     ifelse(
       grepl("}", line, fixed = TRUE),
-      length(gregexpr("}", line, fixed = TRUE)), 0
+      length(gregexpr("}", line, fixed = TRUE)),
+      0
     )
 }
 
@@ -27,17 +29,22 @@ pcd_stan_path <- function() {
 #' @param content Character vector containing Stan code
 #'
 #' @param names_only Logical, if TRUE extract function names, otherwise
-#' extract function content.
+#'  extract function content.
 #'
 #' @param functions Optional, character vector of function names to extract
-#' content for.
+#'   content for.
+#'
 #' @return Character vector of function names or content
+#'
 #' @keywords internal
 .extract_stan_functions <- function(
-    content, names_only = FALSE, functions = NULL) {
+    content,
+    names_only = FALSE,
+    functions = NULL) {
   def_pattern <- "^(real|vector|matrix|void|int|array\\s*<\\s*(real|vector|matrix|int)\\s*>|tuple\\s*<\\s*.*\\s*>)\\s+" # nolint
   func_pattern <- paste0(
-    def_pattern, "(\\w+)\\s*\\("
+    def_pattern,
+    "(\\w+)\\s*\\("
   )
   func_lines <- grep(func_pattern, content, value = TRUE)
   # remove the func_pattern
@@ -57,21 +64,23 @@ pcd_stan_path <- function() {
       end_line <- start_line
       brace_count <- 0
       # Ensure we find the first opening brace
+      # Find first opening brace
       repeat {
-        line <- content[end_line]
-        brace_count <- brace_count + .unmatched_braces(line)
+        brace_count <- brace_count + .unmatched_braces(content[end_line])
         end_line <- end_line + 1
         if (brace_count > 0) break
       }
+
       # Continue until all braces are closed
       repeat {
-        line <- content[end_line]
-        brace_count <- brace_count + .unmatched_braces(line)
+        brace_count <- brace_count + .unmatched_braces(content[end_line])
         if (brace_count == 0) break
         end_line <- end_line + 1
       }
+
       func_content <- c(
-        func_content, paste(content[start_line:end_line], collapse = "\n")
+        func_content,
+        paste(content[start_line:end_line], collapse = "\n")
       )
     }
     return(func_content)
@@ -84,11 +93,11 @@ pcd_stan_path <- function() {
 #' the names of all functions defined in those files.
 #'
 #' @param stan_path Character string specifying the path to the directory
-#' containing Stan files. Defaults to the Stan path of the primarycensored
-#' package.
+#'  containing Stan files. Defaults to the Stan path of the primarycensored
+#'  package.
 #'
 #' @return A character vector containing unique names of all functions found in
-#' the Stan files.
+#'  the Stan files.
 #'
 #' @export
 #'
@@ -97,14 +106,16 @@ pcd_stan_functions <- function(
     stan_path = primarycensored::pcd_stan_path()) {
   stan_files <- list.files(
     stan_path,
-    pattern = "\\.stan$", full.names = TRUE,
+    pattern = "\\.stan$",
+    full.names = TRUE,
     recursive = TRUE
   )
   functions <- character(0)
   for (file in stan_files) {
     content <- readLines(file)
     functions <- c(
-      functions, .extract_stan_functions(content, names_only = TRUE)
+      functions,
+      .extract_stan_functions(content, names_only = TRUE)
     )
   }
   unique(functions)
@@ -152,7 +163,9 @@ pcd_stan_files <- function(
 
     # remove the path from the file names
     matching_files <- sub(
-      paste0(stan_path, "/"), "", matching_files
+      paste0(stan_path, "/"),
+      "",
+      matching_files
     )
     return(matching_files)
   }
@@ -181,12 +194,15 @@ pcd_stan_files <- function(
 #'
 #' @export
 pcd_load_stan_functions <- function(
-    functions = NULL, stan_path = primarycensored::pcd_stan_path(),
-    wrap_in_block = FALSE, write_to_file = FALSE,
+    functions = NULL,
+    stan_path = primarycensored::pcd_stan_path(),
+    wrap_in_block = FALSE,
+    write_to_file = FALSE,
     output_file = "pcd_functions.stan") {
   stan_files <- list.files(
     stan_path,
-    pattern = "\\.stan$", full.names = TRUE,
+    pattern = "\\.stan$",
+    full.names = TRUE,
     recursive = TRUE
   )
   all_content <- character(0)
@@ -247,19 +263,24 @@ pcd_load_stan_functions <- function(
 #' pcd_stan_dist_id("unif", type = "primary")
 pcd_stan_dist_id <- function(name, type = c("delay", "primary")) {
   type <- match.arg(type)
-  df <- switch(type,
+  lookup <- switch(type,
     delay = primarycensored::pcd_distributions,
     primary = primarycensored::pcd_primary_distributions
   )
 
-  match_idx <- which(df$name == name | df$aliases == name)
+  match_idx <- which(lookup$name == name | lookup$aliases == name)
 
   if (length(match_idx) == 0) {
     stop(
-      "No ", type, " distribution found matching: ", name, "\n",
-      .suggest_dist_name(name, type)
+      "No ",
+      type,
+      " distribution found matching: ",
+      name,
+      "\n",
+      .suggest_dist_name(name, type),
+      call. = FALSE
     )
   }
 
-  df$stan_id[match_idx]
+  lookup$stan_id[match_idx]
 }
