@@ -2,11 +2,11 @@
 options(datatable.print.class = FALSE)
 options(datatable.print.keys = FALSE)
 
-if (
-  !on_ci() || not_on_cran()
-) {
-  if (requireNamespace("cmdstanr", quietly = TRUE)) { # nolint
-    if (!is.null(cmdstanr::cmdstan_version())) { # nolint
+if (!on_ci() || not_on_cran()) {
+  # nolint start
+  if (requireNamespace("cmdstanr", quietly = TRUE)) {
+    if (!is.null(cmdstanr::cmdstan_version())) {
+      # nolint end
       library(cmdstanr) # nolint
       temp_path <- file.path(tempdir(), "pcd_stan_functions.stan")
       stan_functions <- pcd_load_stan_functions(
@@ -14,11 +14,14 @@ if (
         write_to_file = TRUE,
         output_file = temp_path
       )
-      model <- suppressMessages(suppressWarnings(
-        cmdstanr::cmdstan_model( # nolint
-          temp_path
+      model <- suppressMessages(
+        suppressWarnings(
+          cmdstanr::cmdstan_model(
+            # nolint
+            temp_path
+          )
         )
-      ))
+      )
       model$expose_functions(global = TRUE)
     }
   }
